---
hide-toc: true
---

(index)=

```{include} ../README.md
:end-before: <img
```

```{image} _static/vcspull-demo.gif
:width: 100%
```

# Donations

```{include} ../README.md
:start-after: "# Donations"
```

```{toctree}
:maxdepth: 2
:hidden:

quickstart
cli/index
configuration/index

```

```{toctree}
:caption: Project
:hidden:

api/index
developing
history
migration
GitHub <https://github.com/vcs-python/vcspull>
```
